/**************************************************************************
// PICO_SIGNATURE
*
* Description:
*   This file contains all the .NET wrapper calls needed to support
*   the console example for the USBPT104. It also has the enums and structs 
*   required by the (wrapped) function calls.
*
***************************************************************************/

using System;
using System.Runtime.InteropServices;
using System.Text;


public class Win32Interop
{
    [DllImport("crtdll.dll")]
    public static extern int _kbhit();
}


namespace USBPT104Imports
{
	class Imports
	{
		#region constants

        private const string _DRIVER_FILENAME = "USBPT104.dll";

        public const short  USBPT104_MIN_WIRES  = 2;
        public const short  USBPT104_3_WIRES    = 3;
        public const short  USBPT104_MAX_WIRES  = 4;

        public const uint   PICO_DRIVER_VERSION                 = 0x00000000;
        public const uint	PICO_USB_VERSION                    = 0x00000001;
        public const uint	PICO_HARDWARE_VERSION               = 0x00000002;
        public const uint	PICO_VARIANT_INFO                   = 0x00000003;
        public const uint	PICO_BATCH_AND_SERIAL               = 0x00000004;
        public const uint	PICO_CAL_DATE                       = 0x00000005;
        public const uint	PICO_KERNEL_VERSION                 = 0x00000006;
    
        public const uint   PICO_DIGITAL_HARDWARE_VERSION       = 0x00000007;
        public const uint   PICO_ANALOGUE_HARDWARE_VERSION      = 0x00000008;
        
        public const uint   PICO_FIRMWARE_VERSION_1             = 0x00000009;
        public const uint   PICO_FIRMWARE_VERSION_2             = 0x0000000A;

        public const uint   PICO_MAC_ADDRESS                    = 0x0000000B;

        public const uint   PICO_OK                             = 0000000000;
        public const uint   PICO_CANCELLED                      = 0x0000003A;
        public const uint   PICO_POWER_SUPPLY_CONNECTED         = 0x00000119;
        public const uint   PICO_POWER_SUPPLY_NOT_CONNECTED     = 0x0000011A;
        public const uint   PICO_POWER_SUPPLY_REQUEST_INVALID   = 0x0000011B;
        public const uint   PICO_POWER_SUPPLY_UNDERVOLTAGE      = 0x0000011C;
        #endregion

		#region Driver enums

        public enum UsbPt104Channels : uint
        {
            USBPT104_CHANNEL_1 = 1,
            USBPT104_CHANNEL_2,
            USBPT104_CHANNEL_3,
            USBPT104_CHANNEL_4,
            USBPT104_CHANNEL_5,
            USBPT104_CHANNEL_6,
            USBPT104_CHANNEL_7,
            USBPT104_CHANNEL_8,
            USBPT104_MAX_CHANNELS = USBPT104_CHANNEL_8
        } // USBPT104_CHANNELS

        public enum UsbPt104DataType : uint
        {
            USBPT104_OFF,
            USBPT104_PT100,
            USBPT104_PT1000,
            USBPT104_RESISTANCE_TO_375R,
            USBPT104_RESISTANCE_TO_10K,
            USBPT104_DIFFERENTIAL_TO_115MV,
            USBPT104_DIFFERENTIAL_TO_2500MV,
            USBPT104_SINGLE_ENDED_TO_115MV ,
            USBPT104_SINGLE_ENDED_TO_2500MV,
            USBPT104_MAX_DATA_TYPES

        } //USBPT104_DATA_TYPES;

        public enum IpDetailsType : uint
        {
            IDT_GET,
            IDT_SET,
        } //IP_DETAILS_TYPE;

        public enum CommunicationType :uint
        {
            CT_USB = 0x00000001,
            CT_ETHERNET = 0x00000002,
            CT_ALL =  0xFFFFFFFF
        } //COMMUNICATION_TYPE;

		#endregion

		#region Driver Imports
		#region Callback delegates
		
		#endregion

        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104OpenUnit")]
        public static extern uint UsbPt104OpenUnit(out short handle,
                                                    StringBuilder serial
                                                    );

        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104CloseUnit")]
        public static extern uint UsbPt104CloseUnit(short handle);


        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104Enumerate")]
        public static extern uint UsbPt104Enumerate(StringBuilder details,
                                                        ref uint stringLength,
                                                        CommunicationType type
                                                    );

        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104GetUnitInfo")]
        public static extern uint UsbPt104GetUnitInfo(short handle,
                                                        StringBuilder str,
                                                        short stringLength,
                                                        ref short requiredSize,
                                                        uint picoInfo
                                                    );

        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104GetValue")]
        public static extern uint UsbPt104GetValue(short handle,
                                                    UsbPt104Channels channel,
                                                    out int value,
                                                    short filtered
                                                    );

        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104IpDetails")]
        public static extern uint UsbPt104IpDetails(short handle,
                                                        ref short enabled,
                                                        StringBuilder ipaddress,
                                                        ref ushort length,
                                                        ref ushort listeningPort,
                                                        IpDetailsType type
                                                    );

        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104OpenUnitViaIp")]
        public static extern uint UsbPt104OpenUnitViaIp(out short handle,
                                                            StringBuilder serial,
                                                            StringBuilder ipAddress
                                                        );

        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104SetChannel")]
        public static extern uint UsbPt104SetChannel(short handle,
                                                        UsbPt104Channels channel,
                                                        UsbPt104DataType type,
                                                        short noOfWires
                                                    );

        [DllImport(_DRIVER_FILENAME, EntryPoint = "UsbPt104SetMains")]
        public static extern uint UsbPt104SetMains(short handle,
                                                    ushort sixty_hertz
                                                    );

		#endregion
	}
}

